%% Backtesting
%
% 05/02/2023

clear;
warning('off','all');

% 1 for GARCH-Copula 
% 2 for GARCH-DCC
model_choice = 1;

% load returns
returns = readmatrix('returns.txt');

n  = size(returns,2)-1; % number of firms (exclude market index)
tc = 0.0005; % 5 basis points proportional transaction cost

smpl = [];
for year = 2007:2020
    for i = 1:12
        smpl = [smpl; datenum(sprintf('%d%02d%d',year,i,eomday(year,i)) , 'yyyymmdd')];
    end
end

tick = [datenum('2007-01-03');smpl];
l    = length(tick);

% used for Mean-MES ratio (MMR)
C1 = 0;
C2 = -0.067;

%% SR + CoSR(C1 = 0, C2 = -6.7%) + GMVP + 1/N

if model_choice == 1
    

    % MMR (C=0)
    
    % specify simulated rets
    name = 'copula_simulated';
    
    % obtain optimal weights
    port_MMR_c1 = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_MMR_c1(:,a) = findweights_MMR(['sim_' int2str(smpl(a)) '.mat'],n,name,C1);
    end
    
    % obtain weights before rebalancing
    port_MMR_c1_before = zeros(n,length(smpl));
    port_MMR_c1_after  = [zeros(n,1) port_MMR_c1]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_MMR_c1_before(:,a) = (port_MMR_c1_after(:,a) .* (1+returns(a,2:end)')) ./...
                                    (1+port_MMR_c1_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_MMR_c1 = cumprod(sum(port_MMR_c1'.*returns(:,2:end),2)+1);
    wealth_MMR_c1 = [1;wealth_MMR_c1];
    
    % final wealth path considering proportional TC
    wealth_MMR_c1_tc = cumprod((sum(port_MMR_c1' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_MMR_c1'-port_MMR_c1_before'),2)));
    wealth_MMR_c1_tc = [1;wealth_MMR_c1_tc];
    
    % cumulative portfolio ret
    ret_MMR_c1 = cumsum(log(1+sum(port_MMR_c1' .*returns(:,2:end),2)));
    ret_MMR_c1 = [0;ret_MMR_c1];
    
    % cumulative portfolio ret considering proportional TC
    ret_MMR_c1_tc = cumsum(log((sum(port_MMR_c1' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_MMR_c1'-port_MMR_c1_before'),2))));
    ret_MMR_c1_tc = [0;ret_MMR_c1_tc];
    
    % compute turnover
    T_MMR_c1 = 0;
    for a = 1:length(smpl)
        T_MMR_c1 = T_MMR_c1 + .5 * sum(abs(port_MMR_c1(:,a)-port_MMR_c1_before(:,a)));
    end
    T_MMR_c1 = T_MMR_c1/length(smpl);
    
    % compute maximum drawdown
    MD_MMR_c1    = maxdrawdown(wealth_MMR_c1);
    MD_MMR_c1_tc = maxdrawdown(wealth_MMR_c1_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of MMR portfolio (C=0) with and without TC using GARCH-Copula are %.3f and %.3f.\n',...
            wealth_MMR_c1_tc(end), wealth_MMR_c1(end))
    fprintf('\n The annual return of MMR portfolio (C=0) with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            power(wealth_MMR_c1_tc(end),1/14)*100-100, power(wealth_MMR_c1(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of MMR portfolio (C=0) with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            MD_MMR_c1_tc*100, MD_MMR_c1*100)
    fprintf('\n The turnoverof MMR portfolio (C=0) using GARCH-Copula is %.3f.\n', T_MMR_c1)
    fprintf('%s\n',repmat('*',11))
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % MMR (C=-6.7%)
    
    % specify simulated rets
    name = 'copula_simulated';
    
    % obtain optimal weights
    port_MMR_c2 = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_MMR_c2(:,a) = findweights_MMR(['sim_' int2str(smpl(a)) '.mat'],n,name,C2);
    end
    
    % obtain weights before rebalancing
    port_MMR_c2_before = zeros(n,length(smpl));
    port_MMR_c2_after  = [zeros(n,1) port_MMR_c2]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_MMR_c2_before(:,a) = (port_MMR_c2_after(:,a) .* (1+returns(a,2:end)')) ./...
                                    (1+port_MMR_c2_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_MMR_c2 = cumprod(sum(port_MMR_c2'.*returns(:,2:end),2)+1);
    wealth_MMR_c2 = [1;wealth_MMR_c2];
    
    % final wealth path considering proportional TC
    wealth_MMR_c2_tc = cumprod((sum(port_MMR_c2' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_MMR_c2'-port_MMR_c2_before'),2)));
    wealth_MMR_c2_tc = [1;wealth_MMR_c2_tc];
    
    % cumulative portfolio ret
    ret_MMR_c2 = cumsum(log(1+sum(port_MMR_c2' .*returns(:,2:end),2)));
    ret_MMR_c2 = [0;ret_MMR_c2];
    
    % cumulative portfolio ret considering proportional TC
    ret_MMR_c2_tc = cumsum(log((sum(port_MMR_c2' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_MMR_c2'-port_MMR_c2_before'),2))));
    ret_MMR_c2_tc = [0;ret_MMR_c2_tc];
    
    % compute turnover
    T_MMR_c2 = 0;
    for a = 1:length(smpl)
        T_MMR_c2 = T_MMR_c2 + .5 * sum(abs(port_MMR_c2(:,a)-port_MMR_c2_before(:,a)));
    end
    T_MMR_c2 = T_MMR_c2/length(smpl);
    
    % compute maximum drawdown
    MD_MMR_c2    = maxdrawdown(wealth_MMR_c2);
    MD_MMR_c2_tc = maxdrawdown(wealth_MMR_c2_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of MMR portfolio (C=-0.067) with and without TC using GARCH-Copula are %.3f and %.3f.\n',...
            wealth_MMR_c2_tc(end), wealth_MMR_c2(end))
    fprintf('\n The annual return of MMR portfolio (C=-0.067) with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            power(wealth_MMR_c2_tc(end),1/14)*100-100, power(wealth_MMR_c2(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of MMR portfolio (C=-0.067) with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            MD_MMR_c2_tc*100, MD_MMR_c2*100)
    fprintf('\n The turnoverof MMR portfolio (C=-0.067) using GARCH-Copula is %.3f.\n', T_MMR_c2)
    fprintf('%s\n',repmat('*',11))
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % 1. SR portfolio
    
    % specify simulated rets
    name = 'copula_simulated';
    
    % obtain optimal weights
    port_SR = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_SR(:,a) = findweights_Sharpe(['sim_' int2str(smpl(a)) '.mat'],n,name);
    end
    
    % obtain weights before rebalancing
    port_SR_before = zeros(n,length(smpl));
    port_SR_after  = [zeros(n,1) port_SR]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_SR_before(:,a) = (port_SR_after(:,a) .* (1+returns(a,2:end)')) ./...
                                (1+port_SR_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_SR = cumprod(sum(port_SR' .*returns(:,2:end),2)+1);
    wealth_SR = [1;wealth_SR];
    
    % final wealth path considering proportional TC
    wealth_SR_tc = cumprod((sum(port_SR' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_SR'-port_SR_before'),2)));
    wealth_SR_tc = [1;wealth_SR_tc];
    
    % cumulative portfolio ret
    ret_SR = cumsum(log(1+sum(port_SR' .*returns(:,2:end),2)));
    ret_SR = [0;ret_SR];
    
    % cumulative portfolio ret considering proportional TC
    ret_SR_tc = cumsum(log((sum(port_SR' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_SR'-port_SR_before'),2))));
    ret_SR_tc = [0;ret_SR_tc];
    
    % compute turnover
    T_SR = 0;
    for a = 1:length(smpl)
        T_SR = T_SR + .5 * sum(abs(port_SR(:,a)-port_SR_before(:,a)));
    end
    T_SR = T_SR/length(smpl);
    
    % compute maximum drawdown
    MD_SR    = maxdrawdown(wealth_SR);
    MD_SR_tc = maxdrawdown(wealth_SR_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of SR portfolio with and without TC using GARCH-Copula are %.3f and %.3f.\n',...
            wealth_SR_tc(end), wealth_SR(end))
    fprintf('\n The annual return of SR portfolio with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            power(wealth_SR_tc(end),1/14)*100-100, power(wealth_SR(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of SR portfolio with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            MD_SR_tc*100, MD_SR*100)
    fprintf('\n The turnoverof SR portfolio using GARCH-Copula is %.3f.\n', T_SR)
    fprintf('%s\n',repmat('*',11))
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % 2. CoSR (C=0)
    
    % specify simulated rets
    name = 'copula_c1';
    
    % obtain optimal weights
    port_c1 = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_c1(:,a) = findweights_Sharpe(['sim_' int2str(smpl(a)) '.mat'],n,name);
    end
    
    % obtain weights before rebalancing
    port_c1_before = zeros(n,length(smpl));
    port_c1_after  = [zeros(n,1) port_c1]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_c1_before(:,a) = (port_c1_after(:,a) .* (1+returns(a,2:end)')) ./...
                                (1+port_c1_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_c1 = cumprod(sum(port_c1' .*returns(:,2:end),2)+1);
    wealth_c1 = [1;wealth_c1];
    
    % final wealth path considering proportional TC
    wealth_c1_tc = cumprod((sum(port_c1' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_c1'-port_c1_before'),2)));
    wealth_c1_tc = [1;wealth_c1_tc];
    
    % cumulative portfolio ret
    ret_c1    = cumsum(log(1+sum(port_c1' .*returns(:,2:end),2)));
    ret_c1    = [0;ret_c1];
    
    % cumulative portfolio ret considering proportional TC
    ret_c1_tc = cumsum(log((sum(port_c1' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_c1'-port_c1_before'),2))));
    ret_c1_tc = [0;ret_c1_tc];
    
    % compute turnover
    T_c1 = 0;
    for a = 1:length(smpl)
        T_c1 = T_c1 + .5 * sum(abs(port_c1(:,a)-port_c1_before(:,a)));
    end
    T_c1 = T_c1/length(smpl);
    
    % compute maximum drawdown
    MD_c1    = maxdrawdown(wealth_c1);
    MD_c1_tc = maxdrawdown(wealth_c1_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of CoSR portfolio (C=0) with and without TC using GARCH-Copula are %.3f and %.3f.\n',...
            wealth_c1_tc(end), wealth_c1(end))
    fprintf('\n The annual return of CoSR portfolio (C=0) with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            power(wealth_c1_tc(end),1/14)*100-100, power(wealth_c1(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of CoSR portfolio (C=0) with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            MD_c1_tc*100, MD_c1*100)
    fprintf('\n The turnoverof CoSR portfolio (C=0) using GARCH-Copula is %.3f.\n', T_c1)
    fprintf('%s\n',repmat('*',11))
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    
    
    % 3. CoSR (C=-0.067)
    % specify simulated rets
    name = 'copula_c2';
    
    % obtain optimal weights
    port_c2 = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_c2(:,a) = findweights_Sharpe(['sim_' int2str(smpl(a)) '.mat'],n,name);
    end
    
    % obtain weights before rebalancing
    port_c2_before = zeros(n,length(smpl));
    port_c2_after  = [zeros(n,1) port_c2]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_c2_before(:,a) = (port_c2_after(:,a) .* (1+returns(a,2:end)')) ./...
                                (1+port_c2_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_c2 = cumprod(sum(port_c2' .*returns(:,2:end),2)+1);
    wealth_c2 = [1;wealth_c2];
    
    % final wealth path considering proportional TC
    wealth_c2_tc = cumprod((sum(port_c2' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_c2'-port_c2_before'),2)));
    wealth_c2_tc = [1;wealth_c2_tc];
    
    % cumulative portfolio ret
    ret_c2    = cumsum(log(1+sum(port_c2' .*returns(:,2:end),2)));
    ret_c2    = [0;ret_c2];
    
    % cumulative portfolio ret considering proportional TC
    ret_c2_tc = cumsum(log((sum(port_c2' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_c2'-port_c2_before'),2))));
    ret_c2_tc = [0;ret_c2_tc];
    
    % compute turnover
    T_c2 = 0;
    for a = 1:length(smpl)
        T_c2 = T_c2 + .5 * sum(abs(port_c2(:,a)-port_c2_before(:,a)));
    end
    T_c2 = T_c2/length(smpl);
    
    % compute maximum drawdown
    MD_c2    = maxdrawdown(wealth_c2);
    MD_c2_tc = maxdrawdown(wealth_c2_tc);
    
    % print out main results
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of CoSR portfolio (C=-0.067) with and without TC using GARCH-Copula are %.3f and %.3f.\n',...
            wealth_c2_tc(end), wealth_c2(end))
    fprintf('\n The annual return of CoSR portfolio (C=-0.067) with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            power(wealth_c2_tc(end),1/14)*100-100, power(wealth_c2(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of CoSR portfolio (C=-0.067) with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            MD_c2_tc*100, MD_c2*100)
    fprintf('\n The turnoverof CoSR portfolio (C=-0.067) using GARCH-Copula is %.3f.\n', T_c2)
    fprintf('%s\n',repmat('*',11))
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % 4. GMVP
    % specify simulated rets
    name = 'copula_simulated';
    
    % obtain optimal weights
    port_GMV = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_GMV(:,a) = findweights_GMV(['sim_' int2str(smpl(a)) '.mat'],n,name);
    end
    
    % obtain weights before rebalancing
    port_GMV_before = zeros(n,length(smpl));
    port_GMV_after  = [zeros(n,1) port_GMV]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_GMV_before(:,a) = (port_GMV_after(:,a) .* (1+returns(a,2:end)')) ./...
                                (1+port_GMV_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_GMV = cumprod(sum(port_GMV' .*returns(:,2:end),2)+1);
    wealth_GMV = [1;wealth_GMV];
    
    % final wealth path considering proportional TC
    wealth_GMV_tc = cumprod((sum(port_GMV' .*returns(:,2:end),2)+1) .* ...
                            (1-tc*sum(abs(port_GMV'-port_GMV_before'),2)));
    wealth_GMV_tc = [1;wealth_GMV_tc];
    
    % cumulative portfolio ret
    ret_GMV = cumsum(log(1+sum(port_GMV' .*returns(:,2:end),2)));
    ret_GMV = [0;ret_GMV];
    
    % cumulative portfolio ret considering proportional TC
    ret_GMV_tc = cumsum(log((sum(port_GMV' .*returns(:,2:end),2)+1) .* ...
                            (1-tc*sum(abs(port_GMV'-port_GMV_before'),2))));
    ret_GMV_tc = [0;ret_GMV_tc];
    
    % compute turnover
    T_GMV = 0;
    for a = 1:length(smpl)
        T_GMV = T_GMV + .5 * sum(abs(port_GMV(:,a)-port_GMV_before(:,a)));
    end
    T_GMV = T_GMV/length(smpl);
    
    % compute maximum drawdown
    MD_GMV    = maxdrawdown(wealth_GMV);
    MD_GMV_tc = maxdrawdown(wealth_GMV_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of GMVP with and without TC using GARCH-Copula are %.3f and %.3f.\n',...
            wealth_GMV_tc(end), wealth_GMV(end))
    fprintf('\n The annual return of GMVP with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            power(wealth_GMV_tc(end),1/14)*100-100, power(wealth_GMV(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of GMVP with and without TC using GARCH-Copula are %4.2f%% and %4.2f%%.\n',...
            MD_GMV_tc*100, MD_GMV*100)
    fprintf('\n The turnoverof GMVP using GARCH-Copula is %.3f.\n', T_GMV)
    fprintf('%s\n',repmat('*',11))
    
    % 5. 1/N portfolio (does not depend on any estimation procedure) 
    port_naive = 1/n .* ones(n,length(smpl));
    
    port_naive_before = zeros(n,length(smpl)); % weights before rebalancing
    port_naive_after  = [zeros(n,1) port_naive]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_naive_before(:,a) = (port_naive_after(:,a) .* (1+returns(a,2:end)')) ./...
                                    (1+port_naive_after(:,a)'*returns(a,2:end)');
    end
    
    wealth_naive    = cumprod(sum(port_naive' .*returns(:,2:end),2)+1);
    wealth_naive    = [1;wealth_naive];
    wealth_naive_tc = cumprod((sum(port_naive' .*returns(:,2:end),2)+1) .* ...
                              (1-tc*sum(abs(port_naive'-port_naive_before'),2)));
    wealth_naive_tc = [1;wealth_naive_tc];
    
    % cumulative portfolio ret
    ret_naive    = cumsum(log(1+sum(port_naive' .*returns(:,2:end),2)));
    ret_naive    = [0;ret_naive];
    
    % cumulative portfolio ret considering proportional TC
    ret_naive_tc = cumsum(log((sum(port_naive' .*returns(:,2:end),2)+1) .* ...
                              (1-tc*sum(abs(port_naive'-port_naive_before'),2))));
    ret_naive_tc = [0;ret_naive_tc];
    
    % compute turnover
    T_naive = 0;
    for a = 1:length(smpl)
        T_naive = T_naive + .5 * sum(abs(port_naive(:,a)-port_naive_before(:,a)));
    end
    T_naive = T_naive/length(smpl);
    
    % compute maximum drawdown
    MD_naive    = maxdrawdown(wealth_naive);
    MD_naive_tc = maxdrawdown(wealth_naive_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of 1/N portfolio with and without TC are %.3f and %.3f.\n',...
            wealth_naive_tc(end), wealth_naive(end))
    fprintf('\n The annual return of 1/N portfolio with and without TC are %4.2f%% and %4.2f%%.\n',...
            power(wealth_naive_tc(end),1/14)*100-100, power(wealth_naive(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of 1/N portfolio with and without TC are %4.2f%% and %4.2f%%.\n',...
            MD_naive_tc*100, MD_naive*100)
    fprintf('\n The turnoverof 1/N portfolio is %.3f.\n', T_naive)
    fprintf('%s\n',repmat('*',11))
    
    %% make table without TC
    VarNames = {'Strategy','SR','CoSR_C1','CoSR_C2','MMR_C1','MMR_C2','GMVP','Naive'};
    strategy = {'Final Wealth';'Annual Return';'Maximum Drawdown'};
    
    sr = [wealth_SR(end);power(wealth_SR(end),1/14)-1;MD_SR];
    cosr1 = [wealth_c1(end);power(wealth_c1(end),1/14)-1;MD_c1];
    cosr2 = [wealth_c2(end);power(wealth_c2(end),1/14)-1;MD_c2];
    mmr1 = [wealth_MMR_c1(end);power(wealth_MMR_c1(end),1/14)-1;MD_MMR_c1];
    mmr2 = [wealth_MMR_c2(end);power(wealth_MMR_c2(end),1/14)-1;MD_MMR_c2];
    gmvp = [wealth_GMV(end);power(wealth_GMV(end),1/14)-1;MD_GMV];
    naive = [wealth_naive(end);power(wealth_naive(end),1/14)-1;MD_naive];
    
    T = table(strategy,round(sr,4),round(cosr1,4),round(cosr2,4),round(mmr1,4),...
                round(mmr2,4),round(gmvp,4),round(naive,4),'VariableNames',VarNames);
    header = 'Backtesting Results for GARCH-Copula Model';
    fprintf('%20c %s \n',' ',header)
    fprintf('\n')
    disp(T)
    
    %% make table with TC
    VarNames = {'Strategy','SR','CoSR_C1','CoSR_C2','MMR_C1','MMR_C2','GMVP','Naive'};
    strategy = {'Final Wealth';'Annual Return';'Maximum Drawdown'};
    
    sr_tc = [wealth_SR_tc(end);power(wealth_SR_tc(end),1/14)-1;MD_SR_tc];
    cosr1_tc = [wealth_c1_tc(end);power(wealth_c1_tc(end),1/14)-1;MD_c1_tc];
    cosr2_tc = [wealth_c2_tc(end);power(wealth_c2_tc(end),1/14)-1;MD_c2_tc];
    mmr1_tc = [wealth_MMR_c1_tc(end);power(wealth_MMR_c1_tc(end),1/14)-1;MD_MMR_c1_tc];
    mmr2_tc = [wealth_MMR_c2_tc(end);power(wealth_MMR_c2_tc(end),1/14)-1;MD_MMR_c2_tc];
    gmvp_tc = [wealth_GMV_tc(end);power(wealth_GMV_tc(end),1/14)-1;MD_GMV_tc];
    naive_tc = [wealth_naive_tc(end);power(wealth_naive_tc(end),1/14)-1;MD_naive_tc];
    
    T = table(strategy,round(sr_tc,4),round(cosr1_tc,4),round(cosr2_tc,4),round(mmr1_tc,4),...
                round(mmr2_tc,4),round(gmvp_tc,4),round(naive_tc,4),'VariableNames',VarNames);
    header = 'Backtesting Results for GARCH-Copula Model with TC';
    fprintf('%20c %s \n',' ',header)
    fprintf('\n')
    disp(T)
    
    %% Plot final wealth without TC
    figure,hold on;
    plot(tick(1:l),wealth_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),wealth_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_SR,'color','b','LineWidth',1)
    plot(tick(1:l),wealth_c1,'color','k','LineWidth',1)
    plot(tick(1:l),wealth_c2,'color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1,'color',rgb('Red'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','CoSR (C=0)','CoSR (C=-6.7%)','MMR (C=0)','MMR (C=-6.7%)','Location','northwest')
    title('Ex-post final wealth paths using a GARCH-Copula model')
    grid on
    grid minor
    
    %% Plot cumulative return without TC
    figure,hold on;
    plot(tick(1:l),ret_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),ret_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_SR,'color','b','LineWidth',1)
    plot(tick(1:l),ret_c1,'color','k','LineWidth',1)
    plot(tick(1:l),ret_c2,'color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),ret_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','CoSR (C=0)','CoSR (C=-6.7%)','MMR (C=0)','MMR (C=-6.7%)','Location','northwest')
    title('Ex-post cumulative return paths using a GARCH-Copula model')
    grid on
    grid minor
    
    
    
    %% Plot final wealth with TC
    figure,hold on;
    plot(tick(1:l),wealth_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),wealth_GMV_tc,':','color','g','LineWidth',1)
    plot(tick(1:l),wealth_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_naive_tc,':','color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_SR,'color','b','LineWidth',1)
    plot(tick(1:l),wealth_SR_tc,':','color','b','LineWidth',1)
    plot(tick(1:l),wealth_c1,'color','k','LineWidth',1)
    plot(tick(1:l),wealth_c1_tc,':','color','k','LineWidth',1)
    plot(tick(1:l),wealth_c2,'color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),wealth_c2_tc,':','color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1_tc,':','color','r','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2_tc,':','color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','GMVP with TC','1/N','1/N with TC','SR','SR with TC','CoSR (C=0)',...
            'CoSR (C=0) with TC','CoSR (C=-6.7%)','CoSR (C=-6.7%) with TC','MMR (C=0)',...
            'MMR (C=0) with TC','MMR (C=-6.7%)','MMR (C=-6.7%) with TC','Location','northwest')
    title('Final wealth paths using a GARCH-Copula model (TC = 5 basis points)')
    grid on
    grid minor
    
    %% Plot cumulative return with TC
    figure,hold on;
    plot(tick(1:l),ret_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),ret_GMV_tc,':','color','g','LineWidth',1)
    plot(tick(1:l),ret_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_naive_tc,':','color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_SR,'color','b','LineWidth',1)
    plot(tick(1:l),ret_SR_tc,':','color','b','LineWidth',1)
    plot(tick(1:l),ret_c1,'color','k','LineWidth',1)
    plot(tick(1:l),ret_c1_tc,':','color','k','LineWidth',1)
    plot(tick(1:l),ret_c2,'color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),ret_c2_tc,':','color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),ret_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c1_tc,':','color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot(tick(1:l),ret_MMR_c2_tc,':','color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','GMVP with TC','1/N','1/N with TC','SR','SR with TC','CoSR (C=0)',...
            'CoSR (C=0) with TC','CoSR (C=-6.7%)','CoSR (C=-6.7%) with TC','MMR (C=0)',...
            'MMR (C=0) with TC','MMR (C=-6.7%)','MMR (C=-6.7%) with TC','Location','northwest')
    title('Cumulative return paths using a GARCH-Copula model (TC = 5 basis points)')
    grid on
    grid minor
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    
    %% Plot final wealth without TC excluding CoSR
    figure,hold on;
    plot(tick(1:l),wealth_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),wealth_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_SR,'color','b','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1,'color',rgb('Red'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','MMR (C=0)','MMR (C=-6.7%)','Location','northwest')
    title('Ex-post final wealth paths using a GARCH-Copula model')
    grid on
    grid minor
    
    %% Plot final wealth without TC for CoSR
    figure,hold on;
    plot(tick(1:l),wealth_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),wealth_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_SR,'color','b','LineWidth',1)
    plot(tick(1:l),wealth_c1,'color',rgb('Red'),'LineWidth',1)
    plot(tick(1:l),wealth_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','CoSR (C=0)','CoSR (C=-6.7%)','Location','northwest')
    title('Ex-post final wealth paths using a GARCH-Copula model')
    grid on
    grid minor
    
    %% Plot cumulative return without TC
    figure,hold on;
    plot(tick(1:l),ret_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),ret_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_SR,'color','b','LineWidth',1)
    plot(tick(1:l),ret_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','MMR (C=0)','MMR (C=-6.7%)','Location','northwest')
    title('Ex-post cumulative return paths using a GARCH-Copula model')
    grid on
    grid minor
    
    
    
    %% Plot final wealth with TC
    figure,hold on;
    plot(tick(1:l),wealth_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),wealth_GMV_tc,':','color','g','LineWidth',1)
    plot(tick(1:l),wealth_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_naive_tc,':','color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_SR,'color','b','LineWidth',1)
    plot(tick(1:l),wealth_SR_tc,':','color','b','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1_tc,':','color','r','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2_tc,':','color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','GMVP with TC','1/N','1/N with TC','SR','SR with TC','MMR (C=0)',...
            'MMR (C=0) with TC','MMR (C=-6.7%)','MMR (C=-6.7%) with TC','Location','northwest')
    title('Final wealth paths using a GARCH-Copula model (TC = 5 basis points)')
    grid on
    grid minor
    
    %% Plot cumulative return with TC
    figure,hold on;
    plot(tick(1:l),ret_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),ret_GMV_tc,':','color','g','LineWidth',1)
    plot(tick(1:l),ret_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_naive_tc,':','color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_SR,'color','b','LineWidth',1)
    plot(tick(1:l),ret_SR_tc,':','color','b','LineWidth',1)
    plot(tick(1:l),ret_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c1_tc,':','color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot(tick(1:l),ret_MMR_c2_tc,':','color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','GMVP with TC','1/N','1/N with TC','SR','SR with TC','MMR (C=0)',...
            'MMR (C=0) with TC','MMR (C=-6.7%)','MMR (C=-6.7%) with TC','Location','northwest')
    title('Cumulative return paths using a GARCH-Copula model (TC = 5 basis points)')
    grid on
    grid minor
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    
    
else
    
    
    % MMR (C=0)
    
    % specify simulated rets
    name = 'dcc_simulated';
    
    % obtain optimal weights
    port_MMR_c1 = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_MMR_c1(:,a) = findweights_MMR(['sim_' int2str(smpl(a)) '.mat'],n,name,C1);
    end
    
    % obtain weights before rebalancing
    port_MMR_c1_before = zeros(n,length(smpl));
    port_MMR_c1_after  = [zeros(n,1) port_MMR_c1]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_MMR_c1_before(:,a) = (port_MMR_c1_after(:,a) .* (1+returns(a,2:end)')) ./...
                                    (1+port_MMR_c1_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_MMR_c1 = cumprod(sum(port_MMR_c1'.*returns(:,2:end),2)+1);
    wealth_MMR_c1 = [1;wealth_MMR_c1];
    
    % final wealth path considering proportional TC
    wealth_MMR_c1_tc = cumprod((sum(port_MMR_c1' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_MMR_c1'-port_MMR_c1_before'),2)));
    wealth_MMR_c1_tc = [1;wealth_MMR_c1_tc];
    
    % cumulative portfolio ret
    ret_MMR_c1 = cumsum(log(1+sum(port_MMR_c1' .*returns(:,2:end),2)));
    ret_MMR_c1 = [0;ret_MMR_c1];
    
    % cumulative portfolio ret considering proportional TC
    ret_MMR_c1_tc = cumsum(log((sum(port_MMR_c1' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_MMR_c1'-port_MMR_c1_before'),2))));
    ret_MMR_c1_tc = [0;ret_MMR_c1_tc];
    
    % compute turnover
    T_MMR_c1 = 0;
    for a = 1:length(smpl)
        T_MMR_c1 = T_MMR_c1 + .5 * sum(abs(port_MMR_c1(:,a)-port_MMR_c1_before(:,a)));
    end
    T_MMR_c1 = T_MMR_c1/length(smpl);
    
    % compute maximum drawdown
    MD_MMR_c1    = maxdrawdown(wealth_MMR_c1);
    MD_MMR_c1_tc = maxdrawdown(wealth_MMR_c1_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of MMR portfolio (C=0) with and without TC using GARCH-DCC are %.3f and %.3f.\n',...
            wealth_MMR_c1_tc(end), wealth_MMR_c1(end))
    fprintf('\n The annual return of MMR portfolio (C=0) with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            power(wealth_MMR_c1_tc(end),1/14)*100-100, power(wealth_MMR_c1(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of MMR portfolio (C=0) with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            MD_MMR_c1_tc*100, MD_MMR_c1*100)
    fprintf('\n The turnoverof MMR portfolio (C=0) using GARCH-DCC is %.3f.\n', T_MMR_c1)
    fprintf('%s\n',repmat('*',11))
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    
    
    % MMR (C=-6.7%)
    
    % specify simulated rets
    name = 'dcc_simulated';
    
    % obtain optimal weights
    port_MMR_c2 = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_MMR_c2(:,a) = findweights_MMR(['sim_' int2str(smpl(a)) '.mat'],n,name,C2);
    end
    
    % obtain weights before rebalancing
    port_MMR_c2_before = zeros(n,length(smpl));
    port_MMR_c2_after  = [zeros(n,1) port_MMR_c2]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_MMR_c2_before(:,a) = (port_MMR_c2_after(:,a) .* (1+returns(a,2:end)')) ./...
                                    (1+port_MMR_c2_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_MMR_c2 = cumprod(sum(port_MMR_c2'.*returns(:,2:end),2)+1);
    wealth_MMR_c2 = [1;wealth_MMR_c2];
    
    % final wealth path considering proportional TC
    wealth_MMR_c2_tc = cumprod((sum(port_MMR_c2' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_MMR_c2'-port_MMR_c2_before'),2)));
    wealth_MMR_c2_tc = [1;wealth_MMR_c2_tc];
    
    % cumulative portfolio ret
    ret_MMR_c2 = cumsum(log(1+sum(port_MMR_c2' .*returns(:,2:end),2)));
    ret_MMR_c2 = [0;ret_MMR_c2];
    
    % cumulative portfolio ret considering proportional TC
    ret_MMR_c2_tc = cumsum(log((sum(port_MMR_c2' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_MMR_c2'-port_MMR_c2_before'),2))));
    ret_MMR_c2_tc = [0;ret_MMR_c2_tc];
    
    % compute turnover
    T_MMR_c2 = 0;
    for a = 1:length(smpl)
        T_MMR_c2 = T_MMR_c2 + .5 * sum(abs(port_MMR_c2(:,a)-port_MMR_c2_before(:,a)));
    end
    T_MMR_c2 = T_MMR_c2/length(smpl);
    
    % compute maximum drawdown
    MD_MMR_c2    = maxdrawdown(wealth_MMR_c2);
    MD_MMR_c2_tc = maxdrawdown(wealth_MMR_c2_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of MMR portfolio (C=-0.067) with and without TC using GARCH-DCC are %.3f and %.3f.\n',...
            wealth_MMR_c2_tc(end), wealth_MMR_c2(end))
    fprintf('\n The annual return of MMR portfolio (C=-0.067) with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            power(wealth_MMR_c2_tc(end),1/14)*100-100, power(wealth_MMR_c2(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of MMR portfolio (C=-0.067) with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            MD_MMR_c2_tc*100, MD_MMR_c2*100)
    fprintf('\n The turnoverof MMR portfolio (C=-0.067) using GARCH-DCC is %.3f.\n', T_MMR_c2)
    fprintf('%s\n',repmat('*',11))
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % 1. SR
    % specify simulated rets
    name = 'dcc_simulated';
    
    % obtain optimal weights
    port_SR = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_SR(:,a) = findweights_Sharpe(['sim_' int2str(smpl(a)) '.mat'],n,name);
    end
    
    % obtain weights before rebalancing
    port_SR_before = zeros(n,length(smpl));
    port_SR_after  = [zeros(n,1) port_SR]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_SR_before(:,a) = (port_SR_after(:,a) .* (1+returns(a,2:end)')) ./...
                                (1+port_SR_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_SR = cumprod(sum(port_SR' .*returns(:,2:end),2)+1);
    wealth_SR = [1;wealth_SR];
    
    % final wealth path considering proportional TC
    wealth_SR_tc = cumprod((sum(port_SR' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_SR'-port_SR_before'),2)));
    wealth_SR_tc = [1;wealth_SR_tc];
    
    % cumulative portfolio ret
    ret_SR    = cumsum(log(1+sum(port_SR' .*returns(:,2:end),2)));
    ret_SR    = [0;ret_SR];
    
    % cumulative portfolio ret considering proportional TC
    ret_SR_tc = cumsum(log((sum(port_SR' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_SR'-port_SR_before'),2))));
    ret_SR_tc = [0;ret_SR_tc];
    
    % compute turnover
    T_SR = 0;
    for a = 1:length(smpl)
        T_SR = T_SR + .5 * sum(abs(port_SR(:,a)-port_SR_before(:,a)));
    end
    T_SR = T_SR/length(smpl);
    
    % compute maximum drawdown
    MD_SR    = maxdrawdown(wealth_SR);
    MD_SR_tc = maxdrawdown(wealth_SR_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of SR portfolio with and without TC using GARCH-DCC are %.3f and %.3f.\n',...
            wealth_SR_tc(end), wealth_SR(end))
    fprintf('\n The annual return of SR portfolio with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            power(wealth_SR_tc(end),1/14)*100-100, power(wealth_SR(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of SR portfolio with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            MD_SR_tc*100, MD_SR*100)
    fprintf('\n The turnoverof SR portfolio using GARCH-DCC is %.3f.\n', T_SR)
    fprintf('%s\n',repmat('*',11))
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % 2. CoSR (C=0)
    % specify simulated rets
    name = 'dcc_c1';
    
    % obtain optimal weights
    port_c1 = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_c1(:,a) = findweights_Sharpe(['sim_' int2str(smpl(a)) '.mat'],n,name);
    end
    
    % obtain weights before rebalancing
    port_c1_before = zeros(n,length(smpl));
    port_c1_after  = [zeros(n,1) port_c1]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_c1_before(:,a) = (port_c1_after(:,a) .* (1+returns(a,2:end)')) ./...
                                (1+port_c1_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_c1    = cumprod(sum(port_c1' .*returns(:,2:end),2)+1);
    wealth_c1    = [1;wealth_c1];
    
    % final wealth path considering proportional TC
    wealth_c1_tc = cumprod((sum(port_c1' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_c1'-port_c1_before'),2)));
    wealth_c1_tc = [1;wealth_c1_tc];
    
    % cumulative portfolio ret
    ret_c1    = cumsum(log(1+sum(port_c1' .*returns(:,2:end),2)));
    ret_c1    = [0;ret_c1];
    
    % cumulative portfolio ret considering proportional TC
    ret_c1_tc = cumsum(log((sum(port_c1' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_c1'-port_c1_before'),2))));
    ret_c1_tc = [0;ret_c1_tc];
    
    % compute turnover
    T_c1 = 0;
    for a = 1:length(smpl)
        T_c1 = T_c1 + .5 * sum(abs(port_c1(:,a)-port_c1_before(:,a)));
    end
    T_c1 = T_c1/length(smpl);
    
    % compute maximum drawdown
    MD_c1    = maxdrawdown(wealth_c1);
    MD_c1_tc = maxdrawdown(wealth_c1_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of CoSR portfolio (C=0) with and without TC using GARCH-DCC are %.3f and %.3f.\n',...
            wealth_c1_tc(end), wealth_c1(end))
    fprintf('\n The annual return of CoSR portfolio (C=0) with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            power(wealth_c1_tc(end),1/14)*100-100, power(wealth_c1(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of CoSR portfolio (C=0) with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            MD_c1_tc*100, MD_c1*100)
    fprintf('\n The turnoverof CoSR portfolio (C=0) using GARCH-DCC is %.3f.\n', T_c1)
    fprintf('%s\n',repmat('*',11))
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % 3. CoSR (C=-0.067)
    % specify simulated rets
    name = 'dcc_c2';
    
    % obtain optimal weights
    port_c2 = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_c2(:,a) = findweights_Sharpe(['sim_' int2str(smpl(a)) '.mat'],n,name);
    end
    
    % obtain weights before rebalancing
    port_c2_before = zeros(n,length(smpl));
    port_c2_after  = [zeros(n,1) port_c2]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_c2_before(:,a) = (port_c2_after(:,a) .* (1+returns(a,2:end)')) ./...
                                (1+port_c2_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_c2    = cumprod(sum(port_c2' .*returns(:,2:end),2)+1);
    wealth_c2    = [1;wealth_c2];
    
    % final wealth path considering proportional TC
    wealth_c2_tc = cumprod((sum(port_c2' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_c2'-port_c2_before'),2)));
    wealth_c2_tc = [1;wealth_c2_tc];
    
    % cumulative portfolio ret
    ret_c2    = cumsum(log(1+sum(port_c2' .*returns(:,2:end),2)));
    ret_c2    = [0;ret_c2];
    
    % cumulative portfolio ret considering proportional TC
    ret_c2_tc = cumsum(log((sum(port_c2' .*returns(:,2:end),2)+1) .* ...
                           (1-tc*sum(abs(port_c2'-port_c2_before'),2))));
    ret_c2_tc = [0;ret_c2_tc];
    
    % compute turnover
    T_c2 = 0;
    for a = 1:length(smpl)
        T_c2 = T_c2 + .5 * sum(abs(port_c2(:,a)-port_c2_before(:,a)));
    end
    T_c2 = T_c2/length(smpl);
    
    % compute maximum drawdown
    MD_c2    = maxdrawdown(wealth_c2);
    MD_c2_tc = maxdrawdown(wealth_c2_tc);
    
    % print out main results
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of CoSR portfolio (C=-0.067) with and without TC using GARCH-DCC are %.3f and %.3f.\n',...
            wealth_c2_tc(end), wealth_c2(end))
    fprintf('\n The annual return of CoSR portfolio (C=-0.067) with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            power(wealth_c2_tc(end),1/14)*100-100, power(wealth_c2(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of CoSR portfolio (C=-0.067) with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            MD_c2_tc*100, MD_c2*100)
    fprintf('\n The turnoverof CoSR portfolio (C=-0.067) using GARCH-DCC is %.3f.\n', T_c2)
    fprintf('%s\n',repmat('*',11))
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % 4. GMVP
    % specify simulated rets
    name = 'dcc_simulated';
    
    % obtain optimal weights
    port_GMV = zeros(n,length(smpl)); 
    parfor a = 1:length(smpl)
        port_GMV(:,a) = findweights_GMV(['sim_' int2str(smpl(a)) '.mat'],n,name);
    end
    
    % obtain weights before rebalancing
    port_GMV_before = zeros(n,length(smpl));
    port_GMV_after  = [zeros(n,1) port_GMV]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_GMV_before(:,a) = (port_GMV_after(:,a) .* (1+returns(a,2:end)')) ./...
                                (1+port_GMV_after(:,a)'*returns(a,2:end)');
    end
    
    % final wealth path
    wealth_GMV    = cumprod(sum(port_GMV' .*returns(:,2:end),2)+1);
    wealth_GMV    = [1;wealth_GMV];
    
    % final wealth path considering proportional TC
    wealth_GMV_tc = cumprod((sum(port_GMV' .*returns(:,2:end),2)+1) .* ...
                            (1-tc*sum(abs(port_GMV'-port_GMV_before'),2)));
    wealth_GMV_tc = [1;wealth_GMV_tc];
    
    % cumulative portfolio ret
    ret_GMV    = cumsum(log(1+sum(port_GMV' .*returns(:,2:end),2)));
    ret_GMV    = [0;ret_GMV];
    
    % cumulative portfolio ret considering proportional TC
    ret_GMV_tc = cumsum(log((sum(port_GMV' .*returns(:,2:end),2)+1) .* ...
                            (1-tc*sum(abs(port_GMV'-port_GMV_before'),2))));
    ret_GMV_tc = [0;ret_GMV_tc];
    
    % compute turnover
    T_GMV = 0;
    for a = 1:length(smpl)
        T_GMV = T_GMV + .5 * sum(abs(port_GMV(:,a)-port_GMV_before(:,a)));
    end
    T_GMV = T_GMV/length(smpl);
    
    % compute maximum drawdown
    MD_GMV    = maxdrawdown(wealth_GMV);
    MD_GMV_tc = maxdrawdown(wealth_GMV_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of GMVP with and without TC using GARCH-DCC are %.3f and %.3f.\n',...
            wealth_GMV_tc(end), wealth_GMV(end))
    fprintf('\n The annual return of GMVP with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            power(wealth_GMV_tc(end),1/14)*100-100, power(wealth_GMV(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of GMVP with and without TC using GARCH-DCC are %4.2f%% and %4.2f%%.\n',...
            MD_GMV_tc*100, MD_GMV*100)
    fprintf('\n The turnoverof GMVP using GARCH-DCC is %.3f.\n', T_GMV)
    fprintf('%s\n',repmat('*',11))
    
    % 5. 1/N portfolio (does not depend on any estimation procedure) 
    port_naive = 1/n .* ones(n,length(smpl));
    
    port_naive_before = zeros(n,length(smpl)); % weights before rebalancing
    port_naive_after  = [zeros(n,1) port_naive]; % satrting weights are a column vector of zeros
    for a = 1:length(smpl)
        port_naive_before(:,a) = (port_naive_after(:,a) .* (1+returns(a,2:end)')) ./...
                                    (1+port_naive_after(:,a)'*returns(a,2:end)');
    end
    
    wealth_naive    = cumprod(sum(port_naive' .*returns(:,2:end),2)+1);
    wealth_naive    = [1;wealth_naive];
    wealth_naive_tc = cumprod((sum(port_naive' .*returns(:,2:end),2)+1) .* ...
                              (1-tc*sum(abs(port_naive'-port_naive_before'),2)));
    wealth_naive_tc = [1;wealth_naive_tc];
    
    % cumulative portfolio ret
    ret_naive  = cumsum(log(1+sum(port_naive' .*returns(:,2:end),2)));
    ret_naive  = [0;ret_naive];
    
    % cumulative portfolio ret considering proportional TC
    ret_naive_tc = cumsum(log((sum(port_naive' .*returns(:,2:end),2)+1) .* ...
                              (1-tc*sum(abs(port_naive'-port_naive_before'),2))));
    ret_naive_tc = [0;ret_naive_tc];
    
    % compute turnover
    T_naive = 0;
    for a = 1:length(smpl)
        T_naive = T_naive + .5 * sum(abs(port_naive(:,a)-port_naive_before(:,a)));
    end
    T_naive = T_naive/length(smpl);
    
    % compute maximum drawdown
    MD_naive    = maxdrawdown(wealth_naive);
    MD_naive_tc = maxdrawdown(wealth_naive_tc);
    
    % print out main results:
    fprintf('%s\n',repmat('*',11))
    fprintf('\n The final wealth of 1/N portfolio with and without TC are %.3f and %.3f.\n',...
            wealth_naive_tc(end), wealth_naive(end))
    fprintf('\n The annual return of 1/N portfolio with and without TC are %4.2f%% and %4.2f%%.\n',...
            power(wealth_naive_tc(end),1/14)*100-100, power(wealth_naive(end),1/14)*100-100)
    fprintf('\n The maximum drawdown of 1/N portfolio with and without TC are %4.2f%% and %4.2f%%.\n',...
            MD_naive_tc*100, MD_naive*100)
    fprintf('\n The turnoverof 1/N portfolio is %.3f.\n', T_naive)
    fprintf('%s\n',repmat('*',11))
    %}
    
%     save('dcc_bt_MMR.mat')
    
    %% load results
    load('dcc_bt_MMR.mat')
    
    %% make table without TC
    VarNames = {'Strategy','SR','CoSR_C1','CoSR_C2','MMR_C1','MMR_C2','GMVP','Naive'};
    strategy = {'Final Wealth';'Annual Return';'Maximum Drawdown'};
    
    sr    = [wealth_SR(end);power(wealth_SR(end),1/14)-1;MD_SR];
    cosr1 = [wealth_c1(end);power(wealth_c1(end),1/14)-1;MD_c1];
    cosr2 = [wealth_c2(end);power(wealth_c2(end),1/14)-1;MD_c2];
    mmr1 = [wealth_MMR_c1(end);power(wealth_MMR_c1(end),1/14)-1;MD_MMR_c1];
    mmr2 = [wealth_MMR_c2(end);power(wealth_MMR_c2(end),1/14)-1;MD_MMR_c2];
    gmvp  = [wealth_GMV(end);power(wealth_GMV(end),1/14)-1;MD_GMV];
    naive = [wealth_naive(end);power(wealth_naive(end),1/14)-1;MD_naive];
    
    T = table(strategy,round(sr,4),round(cosr1,4),round(cosr2,4),round(mmr1,4),...
                round(mmr2,4),round(gmvp,4),round(naive,4),'VariableNames',VarNames);
    header = 'Backtesting Results for GARCH-DCC Model';
    fprintf('%25c %s \n',' ',header)
    fprintf('\n')
    disp(T)
    
    
    %% make table with TC
    VarNames = {'Strategy','SR','CoSR_C1','CoSR_C2','MMR_C1','MMR_C2','GMVP','Naive'};
    strategy = {'Final Wealth';'Annual Return';'Maximum Drawdown'};
    
    sr_tc = [wealth_SR_tc(end);power(wealth_SR_tc(end),1/14)-1;MD_SR_tc];
    cosr1_tc = [wealth_c1_tc(end);power(wealth_c1_tc(end),1/14)-1;MD_c1_tc];
    cosr2_tc = [wealth_c2_tc(end);power(wealth_c2_tc(end),1/14)-1;MD_c2_tc];
    mmr1_tc = [wealth_MMR_c1_tc(end);power(wealth_MMR_c1_tc(end),1/14)-1;MD_MMR_c1_tc];
    mmr2_tc = [wealth_MMR_c2_tc(end);power(wealth_MMR_c2_tc(end),1/14)-1;MD_MMR_c2_tc];
    gmvp_tc = [wealth_GMV_tc(end);power(wealth_GMV_tc(end),1/14)-1;MD_GMV_tc];
    naive_tc = [wealth_naive_tc(end);power(wealth_naive_tc(end),1/14)-1;MD_naive_tc];
    
    T = table(strategy,round(sr_tc,4),round(cosr1_tc,4),round(cosr2_tc,4),round(mmr1_tc,4),...
                round(mmr2_tc,4),round(gmvp_tc,4),round(naive_tc,4),'VariableNames',VarNames);
    header = 'Backtesting Results for GARCH-DCC Model with TC';
    fprintf('%20c %s \n',' ',header)
    fprintf('\n')
    disp(T)
    


    %% Plot final wealth without TC
    figure,hold on;
    plot(tick(1:l),wealth_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),wealth_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_SR,'color','b','LineWidth',1)
    plot(tick(1:l),wealth_c1,'color',rgb('Black'),'LineWidth',1)
    plot(tick(1:l),wealth_c2,'color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1,'color',rgb('Red'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','CoSR (C=0)','CoSR (C=-6.7%)','MMR (C=0)','MMR (C=-6.7%)','Location','northwest')
    title('Ex-post final wealth paths using a GARCH-DCC model')
    grid on
    grid minor
    
    %% Plot cumulative return without TC
    figure,hold on;
    plot(tick(1:l),ret_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),ret_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_SR,'color','b','LineWidth',1)
    plot(tick(1:l),ret_c1,'color',rgb('Black'),'LineWidth',1)
    plot(tick(1:l),ret_c2,'color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),ret_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','CoSR (C=0)','CoSR (C=-6.7%)','MMR (C=0)','MMR (C=-6.7%)','Location','northwest')
    title('Ex-post cumulative return paths using a GARCH-DCC model')
    grid on
    grid minor
    
    %% Plot final wealth with TC
    figure,hold on;
    plot(tick(1:l),wealth_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),wealth_GMV_tc,':','color','g','LineWidth',1)
    plot(tick(1:l),wealth_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_naive_tc,':','color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_SR,'color','b','LineWidth',1)
    plot(tick(1:l),wealth_SR_tc,':','color','b','LineWidth',1)
    plot(tick(1:l),wealth_c1,'color','k','LineWidth',1)
    plot(tick(1:l),wealth_c1_tc,':','color','k','LineWidth',1)
    plot(tick(1:l),wealth_c2,'color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),wealth_c2_tc,':','color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1_tc,':','color','r','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2_tc,':','color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','GMVP with TC','1/N','1/N with TC','SR','SR with TC','CoSR (C=0)',...
            'CoSR (C=0) with TC','CoSR (C=-6.7%)','CoSR (C=-6.7%) with TC','MMR (C=0)',...
            'MMR (C=0) with TC','MMR (C=-6.7%)','MMR (C=-6.7%) with TC','Location','northwest')
    title('Final wealth paths using a GARCH-DCC model (TC = 5 basis points)')
    grid on
    grid minor
    
    %% Plot cumulative return with TC
    figure,hold on;
    plot(tick(1:l),ret_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),ret_GMV_tc,':','color','g','LineWidth',1)
    plot(tick(1:l),ret_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_naive_tc,':','color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_SR,'color','b','LineWidth',1)
    plot(tick(1:l),ret_SR_tc,':','color','b','LineWidth',1)
    plot(tick(1:l),ret_c1,'color','k','LineWidth',1)
    plot(tick(1:l),ret_c1_tc,':','color','k','LineWidth',1)
    plot(tick(1:l),ret_c2,'color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),ret_c2_tc,':','color',rgb('DarkViolet'),'LineWidth',1)
    plot(tick(1:l),ret_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c1_tc,':','color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot(tick(1:l),ret_MMR_c2_tc,':','color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','GMVP with TC','1/N','1/N with TC','SR','SR with TC','CoSR (C=0)',...
            'CoSR (C=0) with TC','CoSR (C=-6.7%)','CoSR (C=-6.7%) with TC','MMR (C=0)',...
            'MMR (C=0) with TC','MMR (C=-6.7%)','MMR (C=-6.7%) with TC','Location','northwest')
    title('Cumulative return paths using a GARCH-DCC model (TC = 5 basis points)')
    grid on
    grid minor
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    
    
    %% Plot final wealth without TC for MMR
    figure,hold on;
    plot(tick(1:l),wealth_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),wealth_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_SR,'color','b','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1,'color',rgb('Red'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','MMR (C=0)','MMR (C=-6.7%)','Location','northwest')
    title('Ex-post final wealth paths using a GARCH-DCC model')
    grid on
    grid minor
    
    %% Plot final wealth without TC for CoSR
    figure,hold on;
    plot(tick(1:l),wealth_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),wealth_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_SR,'color','b','LineWidth',1)
    plot(tick(1:l),wealth_c1,'color',rgb('Red'),'LineWidth',1)
    plot(tick(1:l),wealth_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','CoSR (C=0)','CoSR (C=-6.7%)','Location','northwest')
    title('Ex-post final wealth paths using a GARCH-DCC model')
    grid on
    grid minor
    
    %% Plot cumulative return without TC
    figure,hold on;
    plot(tick(1:l),ret_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),ret_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_SR,'color','b','LineWidth',1)
    plot(tick(1:l),ret_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','MMR (C=0)','MMR (C=-6.7%)','Location','northwest')
    title('Ex-post cumulative return paths using a GARCH-DCC model')
    grid on
    grid minor
    
    %% Plot cumulative return without TC for CoSR
    figure,hold on;
    plot(tick(1:l),ret_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),ret_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_SR,'color','b','LineWidth',1)
    plot(tick(1:l),ret_c1,'color','r','LineWidth',1)
    plot(tick(1:l),ret_c2,'color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','1/N','SR','CoSR (C=0)','CoSR (C=-6.7%)','Location','northwest')
    title('Ex-post cumulative return paths using a GARCH-DCC model')
    grid on
    grid minor
    
    %% Plot final wealth with TC
    figure,hold on;
    plot(tick(1:l),wealth_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),wealth_GMV_tc,':','color','g','LineWidth',1)
    plot(tick(1:l),wealth_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_naive_tc,':','color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),wealth_SR,'color','b','LineWidth',1)
    plot(tick(1:l),wealth_SR_tc,':','color','b','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c1_tc,':','color','r','LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot(tick(1:l),wealth_MMR_c2_tc,':','color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','GMVP with TC','1/N','1/N with TC','SR','SR with TC','MMR (C=0)',...
            'MMR (C=0) with TC','MMR (C=-6.7%)','MMR (C=-6.7%) with TC','Location','northwest')
    title('Final wealth paths using a GARCH-DCC model (TC = 5 basis points)')
    grid on
    grid minor
    
    %% Plot cumulative return with TC
    figure,hold on;
    plot(tick(1:l),ret_GMV,'color','g','LineWidth',1)
    plot(tick(1:l),ret_GMV_tc,':','color','g','LineWidth',1)
    plot(tick(1:l),ret_naive,'color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_naive_tc,':','color',rgb('Orange'),'LineWidth',1)
    plot(tick(1:l),ret_SR,'color','b','LineWidth',1)
    plot(tick(1:l),ret_SR_tc,':','color','b','LineWidth',1)
    plot(tick(1:l),ret_MMR_c1,'color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c1_tc,':','color','r','LineWidth',1)
    plot(tick(1:l),ret_MMR_c2,'color',rgb('Brown'),'LineWidth',1)
    plot(tick(1:l),ret_MMR_c2_tc,':','color',rgb('Brown'),'LineWidth',1)
    plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2);
    plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2);
    plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2);
    plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2);
    plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2);
    plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2);
    plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2);
    plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2);
    hold off
    a = gca;
    a.XTickLabelRotation = 45;
    set(a,'XTick',tick(1:6:l));
    datetick(a,'x','yyyy/mm/dd','keepticks')
    xlim([tick(1) tick(l)]);
    legend('GMVP','GMVP with TC','1/N','1/N with TC','SR','SR with TC','MMR (C=0)',...
            'MMR (C=0) with TC','MMR (C=-6.7%)','MMR (C=-6.7%) with TC','Location','northwest')
    title('Cumulative return paths using a GARCH-DCC model (TC = 5 basis points)')
    grid on
    grid minor

end

%% Plot S&P 500 Index
sp = readmatrix('sp.txt'); % monthly index prices between 2006.12 - 2020-12

figure,hold on;
plot(tick(1:l),sp,'linewidth',2)
plot([tick(19) tick(19)], ylim,'--','color','k','linewidth',2)
plot([tick(31) tick(31)], ylim,'--','color','k','linewidth',2)
plot([tick(40) tick(40)], ylim,'--','color','y','linewidth',2)
plot([tick(61) tick(61)], ylim,'--','color','y','linewidth',2)
plot([tick(103) tick(103)], ylim,'--','color','c','linewidth',2)
plot([tick(115) tick(115)], ylim,'--','color','c','linewidth',2)
plot([tick(157) tick(157)], ylim,'--','color','m','linewidth',2)
plot([tick(end) tick(end)], ylim,'--','color','m','linewidth',2)
hold off
a = gca;
a.XTickLabelRotation = 45;
set(a,'XTick',tick(1:6:l));
datetick(a,'x','yyyy/mm/dd','keepticks')
xlim([tick(1) tick(l)]);
title('S&P 500 Index')
grid on
grid minor
